# Getting started

Account information api information.

## How to Build


You must have Python ```2 >=2.7.9``` or Python ```3 >=3.4``` installed on your system to install and run this SDK. This SDK package depends on other Python packages like nose, jsonpickle etc. 
These dependencies are defined in the ```requirements.txt``` file that comes with the SDK.
To resolve these dependencies, you can use the PIP Dependency manager. Install it by following steps at [https://pip.pypa.io/en/stable/installing/](https://pip.pypa.io/en/stable/installing/).

Python and PIP executables should be defined in your PATH. Open command prompt and type ```pip --version```.
This should display the version of the PIP Dependency Manager installed if your installation was successful and the paths are properly defined.

* Using command line, navigate to the directory containing the generated files (including ```requirements.txt```) for the SDK.
* Run the command ```pip install -r requirements.txt```. This should install all the required dependencies.

![Building SDK - Step 1](https://apidocs.io/illustration/python?step=installDependencies&workspaceFolder=Account%20Information-Python)


## How to Use

The following section explains how to use the Accountinformation SDK package in a new project.

### 1. Open Project in an IDE

Open up a Python IDE like PyCharm. The basic workflow presented here is also applicable if you prefer using a different editor or IDE.

![Open project in PyCharm - Step 1](https://apidocs.io/illustration/python?step=pyCharm)

Click on ```Open``` in PyCharm to browse to your generated SDK directory and then click ```OK```.

![Open project in PyCharm - Step 2](https://apidocs.io/illustration/python?step=openProject0&workspaceFolder=Account%20Information-Python)     

The project files will be displayed in the side bar as follows:

![Open project in PyCharm - Step 3](https://apidocs.io/illustration/python?step=openProject1&workspaceFolder=Account%20Information-Python&projectName=demonstrationapiseb1)     

### 2. Add a new Test Project

Create a new directory by right clicking on the solution name as shown below:

![Add a new project in PyCharm - Step 1](https://apidocs.io/illustration/python?step=createDirectory&workspaceFolder=Account%20Information-Python&projectName=demonstrationapiseb1)

Name the directory as "test"

![Add a new project in PyCharm - Step 2](https://apidocs.io/illustration/python?step=nameDirectory)
   
Add a python file to this project with the name "testsdk"

![Add a new project in PyCharm - Step 3](https://apidocs.io/illustration/python?step=createFile&workspaceFolder=Account%20Information-Python&projectName=demonstrationapiseb1)

Name it "testsdk"

![Add a new project in PyCharm - Step 4](https://apidocs.io/illustration/python?step=nameFile)

In your python file you will be required to import the generated python library using the following code lines

```Python
from demonstrationapiseb1.demonstration_ap_iseb_1_client import DemonstrationAPIseb1Client
```

![Add a new project in PyCharm - Step 4](https://apidocs.io/illustration/python?step=projectFiles&workspaceFolder=Account%20Information-Python&libraryName=demonstrationapiseb1.demonstration_ap_iseb_1_client&projectName=demonstrationapiseb1&className=DemonstrationAPIseb1Client)

After this you can write code to instantiate an API client object, get a controller object and  make API calls. Sample code is given in the subsequent sections.

### 3. Run the Test Project

To run the file within your test project, right click on your Python file inside your Test project and click on ```Run```

![Run Test Project - Step 1](https://apidocs.io/illustration/python?step=runProject&workspaceFolder=Account%20Information-Python&libraryName=demonstrationapiseb1.demonstration_ap_iseb_1_client&projectName=demonstrationapiseb1&className=DemonstrationAPIseb1Client)


## How to Test

You can test the generated SDK and the server with automatically generated test
cases. unittest is used as the testing framework and nose is used as the test
runner. You can run the tests as follows:

  1. From terminal/cmd navigate to the root directory of the SDK.
  2. Invoke ```pip install -r test-requirements.txt```
  3. Invoke ```nosetests```

## Initialization

### 

API client can be initialized as following.

```python

client = DemonstrationAPIseb1Client()
```



# Class Reference

## <a name="list_of_controllers"></a>List of Controllers

* [AccountsController](#accounts_controller)

## <a name="accounts_controller"></a>![Class: ](https://apidocs.io/img/class.png ".AccountsController") AccountsController

### Get controller instance

An instance of the ``` AccountsController ``` class can be accessed from the API Client.

```python
 accounts_controller = client.accounts
```

### <a name="get_returns_a_list_of_transactions_for_one_specific_account_unfiltered_transaction_lists_are_paginated_when_filtering_by_date_results_are_never_paginated"></a>![Method: ](https://apidocs.io/img/method.png ".AccountsController.get_returns_a_list_of_transactions_for_one_specific_account_unfiltered_transaction_lists_are_paginated_when_filtering_by_date_results_are_never_paginated") get_returns_a_list_of_transactions_for_one_specific_account_unfiltered_transaction_lists_are_paginated_when_filtering_by_date_results_are_never_paginated

> Returns a list of transactions for one specific account. You can search on account with or without a date period. The response contains transaction ids that can be used to retrieve transaction details.

```python
def get_returns_a_list_of_transactions_for_one_specific_account_unfiltered_transaction_lists_are_paginated_when_filtering_by_date_results_are_never_paginated(self,
                                                                                                                                                                  accept)
```

#### Parameters

| Parameter | Tags | Description |
|-----------|------|-------------|
| accept |  ``` Required ```  | TODO: Add a parameter description |



#### Example Usage

```python
accept = 'application/json'

accounts_controller.get_returns_a_list_of_transactions_for_one_specific_account_unfiltered_transaction_lists_are_paginated_when_filtering_by_date_results_are_never_paginated(accept)

```


### <a name="get_returns_transaction_details_on_a_specific_transaction"></a>![Method: ](https://apidocs.io/img/method.png ".AccountsController.get_returns_transaction_details_on_a_specific_transaction") get_returns_transaction_details_on_a_specific_transaction

> Depending on transaction type, different fields will be returned. Some types of transaction detail does not have any further details than shown in the original transactions list.

```python
def get_returns_transaction_details_on_a_specific_transaction(self,
                                                                  accept)
```

#### Parameters

| Parameter | Tags | Description |
|-----------|------|-------------|
| accept |  ``` Required ```  | TODO: Add a parameter description |



#### Example Usage

```python
accept = 'application/json'

accounts_controller.get_returns_transaction_details_on_a_specific_transaction(accept)

```


### <a name="get_returns_a_list_of_a_user_s_accounts"></a>![Method: ](https://apidocs.io/img/method.png ".AccountsController.get_returns_a_list_of_a_user_s_accounts") get_returns_a_list_of_a_user_s_accounts

> Listed accounts are those where the user is account holder and where the account type is PSD2 supported.

```python
def get_returns_a_list_of_a_user_s_accounts(self,
                                                with_balance,
                                                accept,
                                                x_request_id,
                                                psu_ip_address,
                                                psu_ip_port,
                                                psu_user_agent,
                                                psu_geo_location,
                                                psu_accept,
                                                psu_accept_charset,
                                                psu_accept_encoding,
                                                psu_accept_language,
                                                psu_http_method,
                                                psu_device_id)
```

#### Parameters

| Parameter | Tags | Description |
|-----------|------|-------------|
| withBalance |  ``` Required ```  | TODO: Add a parameter description |
| accept |  ``` Required ```  | TODO: Add a parameter description |
| xRequestID |  ``` Required ```  | TODO: Add a parameter description |
| pSUIPAddress |  ``` Required ```  | TODO: Add a parameter description |
| pSUIPPort |  ``` Required ```  | TODO: Add a parameter description |
| pSUUserAgent |  ``` Required ```  | TODO: Add a parameter description |
| pSUGeoLocation |  ``` Required ```  | TODO: Add a parameter description |
| pSUAccept |  ``` Required ```  | TODO: Add a parameter description |
| pSUAcceptCharset |  ``` Required ```  | TODO: Add a parameter description |
| pSUAcceptEncoding |  ``` Required ```  | TODO: Add a parameter description |
| pSUAcceptLanguage |  ``` Required ```  | TODO: Add a parameter description |
| pSUHttpMethod |  ``` Required ```  | TODO: Add a parameter description |
| pSUDeviceID |  ``` Required ```  | TODO: Add a parameter description |



#### Example Usage

```python
with_balance = '{{withBalance}}'
accept = 'application/json'
x_request_id = '{{X-Request-ID}}'
psu_ip_address = '{{PSU-IP-Address}}'
psu_ip_port = '{{PSU-IP-Port}}'
psu_user_agent = '{{PSU-User-Agent}}'
psu_geo_location = '{{PSU-Geo-Location}}'
psu_accept = '{{PSU-Accept}}'
psu_accept_charset = '{{PSU-Accept-Charset}}'
psu_accept_encoding = '{{PSU-Accept-Encoding}}'
psu_accept_language = '{{PSU-Accept-Language}}'
psu_http_method = '{{PSU-Http-Method}}'
psu_device_id = '{{PSU-Device-ID}}'

accounts_controller.get_returns_a_list_of_a_user_s_accounts(with_balance, accept, x_request_id, psu_ip_address, psu_ip_port, psu_user_agent, psu_geo_location, psu_accept, psu_accept_charset, psu_accept_encoding, psu_accept_language, psu_http_method, psu_device_id)

```


### <a name="get_returns_account_information_potentially_including_balances_for_one_specific_account"></a>![Method: ](https://apidocs.io/img/method.png ".AccountsController.get_returns_account_information_potentially_including_balances_for_one_specific_account") get_returns_account_information_potentially_including_balances_for_one_specific_account

> Returns account information, with or without balances for one specific account. The accountId is found using the account list endpoint.

```python
def get_returns_account_information_potentially_including_balances_for_one_specific_account(self,
                                                                                                with_balance,
                                                                                                account_id,
                                                                                                accept,
                                                                                                x_request_id,
                                                                                                psu_ip_address,
                                                                                                psu_ip_port,
                                                                                                psu_user_agent,
                                                                                                psu_geo_location,
                                                                                                psu_accept,
                                                                                                psu_accept_charset,
                                                                                                psu_accept_encoding,
                                                                                                psu_accept_language,
                                                                                                psu_http_method,
                                                                                                psu_device_id)
```

#### Parameters

| Parameter | Tags | Description |
|-----------|------|-------------|
| withBalance |  ``` Required ```  | TODO: Add a parameter description |
| accountId |  ``` Required ```  | TODO: Add a parameter description |
| accept |  ``` Required ```  | TODO: Add a parameter description |
| xRequestID |  ``` Required ```  | TODO: Add a parameter description |
| pSUIPAddress |  ``` Required ```  | TODO: Add a parameter description |
| pSUIPPort |  ``` Required ```  | TODO: Add a parameter description |
| pSUUserAgent |  ``` Required ```  | TODO: Add a parameter description |
| pSUGeoLocation |  ``` Required ```  | TODO: Add a parameter description |
| pSUAccept |  ``` Required ```  | TODO: Add a parameter description |
| pSUAcceptCharset |  ``` Required ```  | TODO: Add a parameter description |
| pSUAcceptEncoding |  ``` Required ```  | TODO: Add a parameter description |
| pSUAcceptLanguage |  ``` Required ```  | TODO: Add a parameter description |
| pSUHttpMethod |  ``` Required ```  | TODO: Add a parameter description |
| pSUDeviceID |  ``` Required ```  | TODO: Add a parameter description |



#### Example Usage

```python
with_balance = '{{withBalance}}'
account_id = '{{accountId}}'
accept = 'application/json'
x_request_id = '{{X-Request-ID}}'
psu_ip_address = '{{PSU-IP-Address}}'
psu_ip_port = '{{PSU-IP-Port}}'
psu_user_agent = '{{PSU-User-Agent}}'
psu_geo_location = '{{PSU-Geo-Location}}'
psu_accept = '{{PSU-Accept}}'
psu_accept_charset = '{{PSU-Accept-Charset}}'
psu_accept_encoding = '{{PSU-Accept-Encoding}}'
psu_accept_language = '{{PSU-Accept-Language}}'
psu_http_method = '{{PSU-Http-Method}}'
psu_device_id = '{{PSU-Device-ID}}'

accounts_controller.get_returns_account_information_potentially_including_balances_for_one_specific_account(with_balance, account_id, accept, x_request_id, psu_ip_address, psu_ip_port, psu_user_agent, psu_geo_location, psu_accept, psu_accept_charset, psu_accept_encoding, psu_accept_language, psu_http_method, psu_device_id)

```


[Back to List of Controllers](#list_of_controllers)



